@@ -97,6 +97,9 @@ class MainWgt(qt.QMainWindow):
 
         self.setCentralWidget(self.Main)
 
+    def updateColors(self):
+        self.MainFrameWgt.updateColors()
+
     def onChanged(self, text):
         self.lbl.setText(text)
         self.lbl.adjustSize()
