@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from PySide import QtGui, QtCore
+from calculate.consolegui import qt
 import urllib2
 import OpenSSL, hashlib
 
@@ -23,46 +23,46 @@ from create_cert import RequestCreate
 from client_class import HTTPSClientCertTransport, Client_suds
 import os
 
-class CertClass (QtGui.QWidget):
+class CertClass (qt.QWidget):
     def __init__(self, parent, ClientObj, window):
         self.ClientObj = ClientObj
-        QtGui.QWidget.__init__(self)
+        qt.QWidget.__init__(self)
         
         # get_cert_path
         self.default_cert_path = ClientObj.path_to_cert
 #        self.default_cert_path = self.default_cert_path.replace("~",homePath)
         
-        self.sendlayout = QtGui.QGridLayout()
+        self.sendlayout = qt.QGridLayout()
         self.sendlayout.setContentsMargins(8,8,8,8)
-        self.mainlayout = QtGui.QVBoxLayout()
+        self.mainlayout = qt.QVBoxLayout()
         
         # gen ceth by host
         self.sendlayout.addWidget(LabelWordWrap(_('Host'), self), 0,0)
-        self.send_host = QtGui.QLineEdit('localhost', self)
+        self.send_host = qt.QLineEdit('localhost', self)
         self.sendlayout.addWidget(self.send_host, 0, 1, 1, 2)
         
         self.sendlayout.addWidget(LabelWordWrap(_('Port'), self), 1,0)
         
         cl_core_port = self.ClientObj.VarsApi.Get('core.cl_core_port')
-        self.send_port = QtGui.QLineEdit(cl_core_port, self)
-        self.send_port.setValidator(QtGui.QIntValidator(self))
+        self.send_port = qt.QLineEdit(cl_core_port, self)
+        self.send_port.setValidator(qt.QIntValidator(self))
         self.sendlayout.addWidget(self.send_port, 1, 1, 1, 2)
 
-        layout_button = QtGui.QHBoxLayout()
+        layout_button = qt.QHBoxLayout()
 
-        Send_button = QtGui.QPushButton(_("Send a request"), self)
+        Send_button = qt.QPushButton(_("Send a request"), self)
 #        Send_button.setFixedWidth(140)
         Send_button.clicked.connect(self.send)
         layout_button.addWidget(Send_button)
 
-        Get_button = QtGui.QPushButton(_("Get the certificate"), self)
+        Get_button = qt.QPushButton(_("Get the certificate"), self)
 #        Get_button.setFixedWidth(140)
         Get_button.clicked.connect(self.get)
         layout_button.addWidget(Get_button)
         
-        Quit_button = QtGui.QPushButton(_("Quit"), self)
+        Quit_button = qt.QPushButton(_("Quit"), self)
 #        Quit_button.setFixedWidth(60)
-        Quit_button.setShortcut(QtGui.QKeySequence(QtCore.Qt.Key_Return))
+        Quit_button.setShortcut(qt.QKeySequence(qt.Qt.Key_Return))
         Quit_button.clicked.connect(self.close)
         layout_button.addWidget(Quit_button)
 
@@ -71,7 +71,7 @@ class CertClass (QtGui.QWidget):
         self.sendlayout.setColumnStretch(1,1)
         self.sendlayout.setColumnStretch(2,1)
 
-        self.GroupBoxSend = QtGui.QGroupBox(_("Certificate signature request"))
+        self.GroupBoxSend = qt.QGroupBox(_("Certificate signature request"))
 #        self.GroupBoxSend.setContentsMargins(10,0,0,0)
         self.GroupBoxSend.setLayout(self.sendlayout)
 
@@ -79,7 +79,7 @@ class CertClass (QtGui.QWidget):
         self.setLayout(self.mainlayout)
         self.setFocus()
         # for clear memory after closed this window
-        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setAttribute(qt.Qt.WA_DeleteOnClose)
 
         self.setFixedSize(self.sizeHint().width(), self.sizeHint().height())
         self.move(window.geometry().x() + window.geometry().width() / 2 \
@@ -88,7 +88,7 @@ class CertClass (QtGui.QWidget):
                   - self.size().height() / 2 - 50)  
 
         self.setWindowTitle (_('Certificates'))
-        self.setWindowIcon (QtGui.QIcon.fromTheme("view-certificate"))
+        self.setWindowIcon (qt.QIcon.fromTheme("view-certificate"))
 
     def send(self):
     ### client_post_request analog
@@ -116,10 +116,10 @@ class CertClass (QtGui.QWidget):
             reply = show_question(self, text, informative_text,
                                   title = _('Calculate Console'))
 
-            if reply == QtGui.QMessageBox.No:
+            if reply == qt.QMessageBox.No:
                 return 0
 
-            elif reply == QtGui.QMessageBox.Yes:
+            elif reply == qt.QMessageBox.Yes:
                 pass
 
         url = "https://%s:%d/?wsdl" %(by_host, int(port))
@@ -159,18 +159,18 @@ class CertClass (QtGui.QWidget):
             reply = show_question(self, text, informative_text,
                                   title = _('Calculate Console'))
             
-            if reply == QtGui.QMessageBox.Yes:
+            if reply == qt.QMessageBox.Yes:
                 self.req_obj = RequestCreate(self, self.ClientObj, key, \
                                              cert_path, server_host_name)
                 self.req_obj.show()
                     
-            elif reply == QtGui.QMessageBox.No:
+            elif reply == qt.QMessageBox.No:
                 pass
 
         else:
             self.req_obj = RequestCreate(self, self.ClientObj, key, \
                                          cert_path, server_host_name)
-            self.req_obj.setAttribute(QtCore.Qt.WA_ShowModal)
+            self.req_obj.setWindowModality(qt.Qt.WindowModal)
             self.req_obj.show()
 
     def end_send(self):
