@@ -348,25 +348,35 @@ class ToolTabWidget(qt.QTabWidget):
 
         self.connect_dict = {}
         self.connect_count = 0
-
         if not host or host == 'localhost':
-            host = '127.0.0.1'
+            self.host = '127.0.0.1'
+        else:
+            self.host = host
         if not port:
-            port = self.VarsGui.GetInteger('core.cl_core_port')
-        self.FirstWidget.connect_to_localhost(host, port)
-        if self.FirstWidget.ClientObj.client:
-            if host in ['127.0.0.1', 'localhost']:
-                self.localhost_ClientObj = self.FirstWidget.ClientObj
-            if not host in self.connect_dict:
-                self.connect_dict[host] = [port]
-            else:
-                if port:
-                    if not port in self.connect_dict[host]:
-                        self.connect_dict[host].append(port)
+            self.port = self.VarsGui.GetInteger('core.cl_core_port')
+        else:
+            self.port = port
+
+        self.setEnabled(False)
+        qt.QTimer.singleShot(200, self.connect_after_init)
         self.create_tray()
         if self.FirstWidget.ClientObj.client:
             self.tray.set_icon(True)
 
+    def connect_after_init(self):
+        self.FirstWidget.connect_to_localhost(self.host, self.port)
+        self.setEnabled(True)
+        if self.FirstWidget.ClientObj.client:
+            self.FirstWidget.updateColors()
+            if self.host in ['127.0.0.1', 'localhost']:
+                self.localhost_ClientObj = self.FirstWidget.ClientObj
+            if not self.host in self.connect_dict:
+                self.connect_dict[self.host] = [self.port]
+            else:
+                if self.port:
+                    if not self.port in self.connect_dict[self.host]:
+                        self.connect_dict[self.host].append(self.port)
+
     def set_offline_icon(self):
         if self.current_icon != "offline":
             self.current_icon = "offline"
