@@ -15,21 +15,22 @@
 #  limitations under the License.
 
 
-from PySide import QtGui, QtCore
+from calculate.consolegui import qt
 from more import TopMenu, HelpMenu#, FlowLayout
 
-class MainMenu(QtGui.QWidget):
+class MainMenu(qt.QWidget):
     def __init__(self, parent):
-        QtGui.QWidget.__init__(self, parent)
+        qt.QWidget.__init__(self, parent)
 #        self.hlayout = FlowLayout(self)
-        QtGui.QIcon.setThemeName('Calculate')
-        self.hlayout = QtGui.QHBoxLayout(self)
-        self.hlayout.setAlignment(QtCore.Qt.AlignLeft)
+        qt.QIcon.setThemeName('Calculate')
+        self.hlayout = qt.QHBoxLayout(self)
+        self.hlayout.setAlignment(qt.Qt.AlignLeft)
 
 ######### Back on one step
-        self.Back = TopMenu(_('Back'),['go-previous'], self)
-        self.Back.setStatusTip(_('Back'))
-        self.Back.setToolTip(_('Back'))
+        self.Back = TopMenu(_('All Settings'),
+            ['calculate-toolbar-all-settings', 'go-previous'], self)
+        self.Back.setStatusTip(_('All settings'))
+        self.Back.setToolTip(_('All settings'))
         self.Back.clicked.connect(parent.back)
         self.Back.setVisible(False)
         self.hlayout.addWidget(self.Back)
@@ -44,8 +45,8 @@ class MainMenu(QtGui.QWidget):
 #        self.hlayout.addWidget(self.Methods)
 
 ######### View information about the running processes
-        self.Processes = TopMenu(_('Processes'),['system-run', \
-                                                'applications-system'], self)
+        self.Processes = TopMenu(_('Processes'),['calculate-toolbar-processes',
+                                                 'applications-system'], self)
         self.Processes.setStatusTip(_('View information about running '
                                     'processes'))
         self.Processes.setToolTip(_('View information about running '
@@ -55,8 +56,10 @@ class MainMenu(QtGui.QWidget):
         self.hlayout.addWidget(self.Processes)
 
 ######### View information about current session
-        self.Session = TopMenu(_('Session'), ['document-edit-verify', \
-                                         'document-revert','edit-find'], self)
+        self.Session = TopMenu(_('Session'), ['calculate-toolbar-session', 
+                                              'document-edit-verify',
+                                              'document-revert','edit-find'],
+                                              self)
         self.Session.setStatusTip \
                             (_('View information about the current session'))
         self.Session.setToolTip \
@@ -66,8 +69,9 @@ class MainMenu(QtGui.QWidget):
         self.hlayout.addWidget(self.Session)
 
 ######### Exit this session
-        self.Disconnect = TopMenu(_('Disconnect'), \
-                            ['network-disconnect', 'connect_no'], self)
+        self.Disconnect = TopMenu(_('Disconnect'),
+                            ['calculate-toolbar-disconnect',
+                             'network-disconnect', 'connect_no'], self)
         self.Disconnect.setStatusTip(_('Disconnect'))
         self.Disconnect.setToolTip(_('Disconnect from the current server'))
         self.Disconnect.clicked.connect(parent.disconnect)
@@ -76,7 +80,8 @@ class MainMenu(QtGui.QWidget):
 
 ######### Connection
         self.Connect = TopMenu(_('Connect'), \
-                            ['network-connect','connect_established'], self)
+                            ['calculate-toolbar-connect',
+                             'network-connect','connect_established'], self)
         self.Connect.setStatusTip(_('Connect'))
         self.Connect.setToolTip(_('Connect'))
         self.Connect.clicked.connect(parent.connecting)
@@ -84,23 +89,26 @@ class MainMenu(QtGui.QWidget):
 
 ######### Window work with certificates
         self.Certificates = TopMenu(_('Certificates'), \
-                        ['view-certificate', 'application-certificate'], self)
+                        ['calculate-toolbar-certificates',
+                         'view-certificate', 'application-certificate'], self)
         self.Certificates.setStatusTip(_('Certificates manager'))
         self.Certificates.setToolTip(_('Certificates manager'))
         self.Certificates.clicked.connect(parent.work_with_certificates)
         self.hlayout.addWidget(self.Certificates)
 
 ######### Tools dialog
-        self.Tool = TopMenu(_('Tools'),['preferences-other', \
-                                                  'preferences-system'], self)
+        self.Tool = TopMenu(_('Tools'),['calculate-toolbar-tools',
+                                        'preferences-other',
+                                        'preferences-system'], self)
         self.Tool.setStatusTip(_('Application settings'))
         self.Tool.setToolTip(_('Application settings'))
         self.Tool.clicked.connect(parent.tools)
         self.hlayout.addWidget(self.Tool)
 
 ######### View help information
-        self.Help = HelpMenu(_('Help'),['help-about','help-browser'], \
-                    parent, parent.ClientObj._parent)
+        self.Help = HelpMenu(_('Help'),
+            ['calculate-toolbar-help', 'help-about','help-browser'],
+            parent, parent.ClientObj._parent)
         self.Help.setStatusTip(_('Help'))
         self.hlayout.addWidget(self.Help)
 
@@ -118,13 +126,13 @@ class MainMenu(QtGui.QWidget):
 
 #        self.setFixedHeight(48)
         self.setFixedHeight(self.hlayout.sizeHint().height())
-        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setAttribute(qt.Qt.WA_DeleteOnClose)
 
     def refresh(self):
 ######### Back on one step
-        self.Back.setText(_('Back'))
-        self.Back.setStatusTip(_('Back'))
-        self.Back.setToolTip(_('Back'))   
+        self.Back.setText(_('All Settings'))
+        self.Back.setStatusTip(_('All settings'))
+        self.Back.setToolTip(_('All settings'))
 
 ######### View information about the running processes
         self.Processes.setText(_('Processes'))
@@ -156,9 +164,9 @@ class MainMenu(QtGui.QWidget):
         self.Certificates.setToolTip(_('Certificates manager'))
 
 ######### Tools dialog
-        self.Tool.setText(_('Tools'))
-        self.Tool.setStatusTip(_('Application settings'))
-        self.Tool.setToolTip(_('Application settings'))
+        self.Tool.setText(_('Preferences'))
+        self.Tool.setStatusTip(_('Application preferences'))
+        self.Tool.setToolTip(_('Application preferences'))
 
 ######### View help information
         self.Help.setText(_('Help'))
